@@ -366,10 +366,10 @@ class Ui_MainWindow(object):
         b = None
         # X-term - grab 10 buffered front camera images, and throw them into an image file.
         # Everyone recommends 1.... but 10 gave more light! - so i used it :D
-        b = os.popen('gst-launch v4l2camsrc device=/dev/video1 num-buffers=10 ! dspjpegenc ! filesink location=fcamtest.jpg')
+        b = os.popen('gst-launch v4l2camsrc device=/dev/video1 num-buffers=10 ! dspjpegenc ! filesink location=/home/user/MyDocs/fcamtest.jpg')
         b.close ()
         # Declare and set the image file name
-        image_file = "fcamtest.jpg"
+        image_file = "/home/user/MyDocs/fcamtest.jpg"
         image = QtGui.QPixmap(image_file)
         # Declare image, and tell it, that it is a pixmap, and it will be a pixmap of the file we have just set.
         self.lbl_CameraShow.setPixmap(image)
